@@ -16,6 +16,8 @@ from data_product_sdk.cortex_databricks.data_platform.processing_utils import (
 )
 from data_product_sdk.cortex_databricks.data_platform.profiling_utils import (
     calculate_profilling,
+    get_link_table
+    
 )
 from data_product_sdk.cortex_databricks.data_platform.schema_utils import (
     get_schema_from_s3,
@@ -27,6 +29,8 @@ from data_product_sdk.cortex_databricks.data_platform.spark_utils import (
     get_table_partitions,
     drop_table_duplicates,
     build_matching_sort_condition,
+    set_comment_table
+
 )
 from delta.tables import DeltaTable
 from pyspark.sql import SparkSession
@@ -717,7 +721,8 @@ def bronze_to_silver(
                             'columns_count',
                             'rows_count',
                             'last_update',
-                            'create_date'
+                            'create_date',
+                            'table_url',
                         ]
                 values = [
                         (
@@ -732,13 +737,16 @@ def bronze_to_silver(
                             tbl_properties.get('cortex.rowsCount'),
                             tbl_properties.get('cortex.lastUpdate'),
                             tbl_properties.get('cortex.createDate'),
+                            get_link_table(catalog_name, 'silver', output_db_table)
                         )
                     ]
                 df_governance = spark.createDataFrame(values, columns)
                 df_governance.write.option("header", "true")\
                     .format('delta')\
                     .mode('append')\
-                    .saveAsTable("cortex.data_governance_quality.datasets")
+                    .saveAsTable("cortex.data_governance_quality.tables")
+                
+                set_comment_table(catalog_name, f'silver.{output_db_table}'  , tbl_properties.get('cortex.description'))
 
             except Exception as e:
                 print(e)
@@ -863,7 +871,8 @@ def silver_to_gold(
                             'rows_count',
                             'last_update',
                             'create_date',
-                            'exposures'
+                            'exposures',
+                            'table_url'
                         ]
                 values = [
                         (
@@ -878,14 +887,16 @@ def silver_to_gold(
                             tbl_properties.get('cortex.rowsCount'),
                             tbl_properties.get('cortex.lastUpdate'),
                             tbl_properties.get('cortex.createDate'),
-                            tbl_properties.get('cortex.exposures')
+                            tbl_properties.get('cortex.exposures'),
+                            get_link_table(catalog_name, 'gold', output_db_table)
                         )
                     ]
                 df_governance = spark.createDataFrame(values, columns)
                 df_governance.write.option("header", "true")\
                     .format('delta')\
                     .mode('append')\
-                    .saveAsTable("cortex.data_governance_quality.datasets")
+                    .saveAsTable("cortex.data_governance_quality.tables")
+                set_comment_table(catalog_name, f'gold.{output_db_table}'  , tbl_properties.get('cortex.description'))
 
             except Exception as e:
                 print(e)
